<?php

namespace Foo;

/**
 * class VeryLongHeredoc { }
 */
class VeryLongHeredoc
{
    public function test_heredoc()
    {
        return <<<HEREDOC
Cupcake ipsum dolor sit amet. Gingerbread macaroon cake caramels tiramisu shortbread caramels. Lollipop toffee
sugar plum liquorice tiramisu muffin. Sugar plum pie croissant lemon drops candy canes marshmallow sesame snaps
candy. Candy candy canes gingerbread soufflé lemon drops caramels jelly croissant. Croissant bonbon I love candy
canes fruitcake. I love ice cream I love bonbon carrot cake carrot cake gingerbread. Powder gummies I love ice
cream marzipan. Cupcake toffee carrot cake sugar plum I love macaroon candy carrot cake jelly-o. Gingerbread
donut icing danish donut tart. I love ice cream pastry bonbon gingerbread sugar plum I love muffin powder. Wafer
ice cream donut cheesecake dragée tart marshmallow cheesecake.

Soufflé wafer cupcake biscuit I love candy canes gingerbread danish dessert. Bear claw I love sesame snaps
liquorice jelly-o lemon drops. Toffee sesame snaps chocolate chocolate powder pie chocolate bar tootsie roll
sweet roll. Gummies I love pastry sweet lollipop. Chocolate cake sugar plum I love powder apple pie. Cake I love
powder marshmallow sesame snaps. Dessert brownie tootsie roll topping gummi bears ice cream candy. Jujubes
carrot cake I love fruitcake lemon drops croissant macaroon toffee dessert. Chocolate gummies cookie jelly-o
wafer gummi bears macaroon. Pudding icing dragée chocolate cake pie liquorice topping jelly beans. Lollipop
gummi bears chocolate jelly beans dessert shortbread macaroon jelly beans. Cupcake lemon drops halvah fruitcake
cookie dessert icing. I love icing gummies tart carrot cake dragée. Macaroon cake tootsie roll sweet roll wafer
apple pie oat cake.

Lollipop cotton candy dessert gummies caramels lollipop. Marshmallow bear claw biscuit chocolate croissant
marshmallow. Pudding liquorice chocolate cake bear claw candy canes I love cupcake tiramisu I love. Marzipan I
love sweet roll jelly gummi bears bear claw gummi bears jelly-o cheesecake. Candy fruitcake gummi bears lemon
drops wafer lemon drops cheesecake liquorice. Topping I love ice cream cupcake chocolate bar jelly bear claw.
Sugar plum I love wafer macaroon icing danish. Gummi bears liquorice brownie chocolate bar candy fruitcake
marzipan cake dragée. Toffee I love bonbon cookie jujubes gingerbread ice cream cheesecake caramels. Sesame
snaps shortbread I love I love jelly-o jelly. Candy cupcake cake I love tart chocolate cake I love toffee.
Gingerbread I love muffin bonbon donut cupcake candy canes cheesecake. Brownie cookie I love tart pudding
cupcake I love marzipan pastry. Jelly tart carrot cake I love wafer muffin candy dragée cupcake.

Carrot cake I love jelly-o gingerbread danish cotton candy chocolate cake gummies cake. Chupa chups donut I love
topping jelly beans cake gingerbread. Jujubes jujubes croissant jujubes halvah jelly-o chupa chups marshmallow.
Chocolate bar marzipan I love cookie biscuit jelly cheesecake. Sesame snaps jelly beans topping marzipan
fruitcake chocolate bar. Donut dessert I love cake lollipop I love cookie danish sweet roll. Tiramisu jelly
liquorice jelly cupcake I love sugar plum marshmallow I love. Dragée dessert dragée fruitcake biscuit wafer
halvah. Jujubes I love bear claw tart lemon drops. Sesame snaps danish danish cake fruitcake toffee. Jujubes pie
bonbon powder lemon drops oat cake I love sugar plum chocolate bar. Lemon drops sesame snaps dragée sugar plum
tootsie roll apple pie donut biscuit jelly beans. Toffee marzipan oat cake icing wafer.

Candy canes sweet roll jelly-o jelly sugar plum lemon drops jelly beans. Jelly chocolate bar dragée I love
dessert cheesecake shortbread chupa chups. Donut cookie marzipan bear claw tootsie roll. Sweet muffin
gingerbread sweet chocolate bar cake dessert chocolate cake chocolate. Chocolate bar chocolate cake soufflé
dragée I love. Jelly gummies bonbon chupa chups dessert jelly-o. Sesame snaps bear claw I love fruitcake candy
apple pie. Candy canes marzipan croissant dessert wafer ice cream biscuit. Lemon drops biscuit dessert tart I
love shortbread shortbread oat cake brownie. Dessert I love tootsie roll wafer cotton candy. Wafer pastry candy
chupa chups I love. Chupa chups cheesecake soufflé donut apple pie wafer. Pudding I love chocolate cake caramels
I love powder I love sweet tiramisu.

Donut muffin I love pastry caramels chocolate bar sweet. Marshmallow topping cookie muffin wafer bonbon marzipan
chupa chups chocolate cake. Candy sugar plum cake cake I love. Oat cake donut I love liquorice caramels marzipan
cake. Gummi bears caramels pie fruitcake ice cream chocolate. Brownie wafer chupa chups fruitcake carrot cake
cookie chupa chups apple pie chocolate cake. Tart pie donut sweet roll chocolate bar jelly-o. Toffee icing I
love cake shortbread lollipop tiramisu candy marshmallow. I love I love candy canes cupcake chupa chups cake
jelly-o I love. I love jujubes I love liquorice soufflé. Brownie dragée sesame snaps sesame snaps sesame snaps I
love ice cream. Apple pie topping carrot cake dessert powder powder cotton candy candy apple pie.

Wafer lollipop brownie marzipan jujubes chocolate. Jelly beans tiramisu jelly beans sugar plum I love gummi
bears cheesecake cheesecake. Pie macaroon macaroon halvah jelly-o. Oat cake candy canes lollipop candy donut
powder gummies soufflé caramels. Chupa chups pudding I love gummies chupa chups jelly beans bear claw. Liquorice
lemon drops chocolate bar cheesecake danish gummies chupa chups jelly jelly beans. Jelly-o lollipop I love
tootsie roll chupa chups icing jujubes macaroon gingerbread. Sweet chocolate cake cake carrot cake I love
topping tart jujubes I love. Apple pie I love marshmallow I love icing I love danish dragée. Icing tootsie roll
macaroon tart liquorice. Gummies macaroon dragée candy tiramisu jelly I love jelly I love. Chocolate cotton
candy cookie I love halvah I love dessert cupcake marshmallow.

Chocolate gummi bears caramels gummies gummi bears carrot cake apple pie fruitcake bear claw. Sesame snaps
powder jelly sweet croissant. Chocolate liquorice cake cake marshmallow danish bonbon jelly. Carrot cake pudding
bear claw sweet roll cotton candy topping danish gummies. Chocolate cake bonbon oat cake cookie muffin jujubes
sweet roll. Cake sesame snaps gingerbread chocolate cake shortbread cheesecake chocolate bar danish. Sweet roll
apple pie brownie brownie dragée tootsie roll marshmallow brownie. I love carrot cake topping fruitcake pudding.
Cookie jelly chocolate bar sweet pastry. Cheesecake halvah wafer icing danish. Tootsie roll liquorice jujubes
dessert sweet roll shortbread croissant cookie chupa chups. Fruitcake lemon drops topping bear claw oat cake I
love cake sweet roll. Candy canes oat cake topping I love macaroon.

Dessert sugar plum lollipop macaroon I love gingerbread I love oat cake chupa chups. Carrot cake chocolate cake
candy caramels bonbon powder soufflé chocolate bar cookie. Pie brownie I love jelly-o I love. Brownie jelly
beans pie I love jelly jelly beans. Jelly carrot cake macaroon cupcake bonbon I love jujubes tootsie roll.
Caramels powder wafer jelly beans lemon drops sweet topping gummies. Chupa chups dessert lollipop apple pie
sesame snaps sugar plum lollipop dragée jujubes. Candy toffee pie tiramisu chocolate bar I love. I love I love
shortbread bear claw soufflé candy canes I love jelly beans. Cupcake pudding powder oat cake muffin I love cake
chocolate cake. Ice cream brownie tart icing cheesecake jelly-o chocolate bar bear claw. Halvah bear claw
marzipan chocolate cake toffee croissant.

Marshmallow tart gummi bears sugar plum donut candy canes powder. Cake chocolate cake tiramisu brownie danish
caramels liquorice. Jelly beans I love pastry candy canes muffin sesame snaps powder soufflé donut. Muffin
marshmallow carrot cake donut powder cookie. Macaroon chupa chups chupa chups jelly beans ice cream brownie
lemon drops I love. Biscuit croissant oat cake pastry halvah macaroon. Tart candy canes sesame snaps I love
pastry cotton candy. Soufflé I love dessert cake gummi bears lollipop. Chocolate bar I love liquorice bonbon
gummies brownie chupa chups cookie. Lemon drops pudding muffin caramels wafer powder. Donut brownie biscuit
biscuit I love chocolate. I love biscuit sugar plum tiramisu chocolate cake bonbon.

Shortbread oat cake chupa chups topping caramels gummies. Tiramisu toffee I love bonbon candy canes. Tootsie
roll halvah pie cake fruitcake wafer pudding tootsie roll. Icing danish cookie danish cookie donut shortbread.
Jujubes pie tiramisu tiramisu pie halvah. Liquorice jelly marshmallow brownie bear claw marshmallow. Liquorice
toffee pie I love cake. Jelly I love jelly-o caramels carrot cake pastry cotton candy cake. I love I love
marshmallow tootsie roll bonbon. Cotton candy brownie caramels I love dragée bear claw oat cake chocolate bar
bear claw. Donut sugar plum shortbread fruitcake carrot cake wafer tart jujubes fruitcake. Chupa chups cake
muffin gummies soufflé I love candy. Powder fruitcake candy I love chocolate toffee ice cream chocolate bar
dessert.

Icing ice cream lollipop danish I love macaroon candy cotton candy chocolate cake. Powder pie sweet soufflé
shortbread I love tiramisu candy. Gummies topping croissant chocolate cake jelly beans toffee. Dessert I love I
love candy canes chupa chups. Chocolate sugar plum I love gummies shortbread wafer I love jelly-o. Jujubes
halvah macaroon sesame snaps jelly beans sweet roll muffin liquorice I love. Tiramisu jelly liquorice cotton
candy donut soufflé. Tootsie roll oat cake I love gingerbread chocolate biscuit. Donut pastry candy marshmallow
gingerbread wafer topping bear claw. Shortbread cake macaroon chupa chups ice cream gummi bears liquorice
gingerbread. Cotton candy tootsie roll donut gummies biscuit chocolate cake. Gingerbread jujubes caramels sweet
chocolate cake soufflé. Apple pie cotton candy chocolate bar jelly-o muffin brownie pie.

Cotton candy tootsie roll cookie gummies muffin croissant marshmallow. Sweet jujubes gummi bears gummies
liquorice. Tart pudding icing gingerbread bear claw sweet liquorice. Icing danish cake biscuit bonbon. Bonbon
candy canes topping icing sugar plum fruitcake sweet roll jelly-o candy. Marshmallow tart macaroon apple pie ice
cream. Tart brownie cotton candy croissant dessert topping liquorice I love marzipan. Tart liquorice lollipop
cookie jelly bonbon sesame snaps liquorice chupa chups. Chupa chups jelly-o sweet candy canes sesame snaps.
Tootsie roll soufflé I love marzipan I love I love lemon drops. Sugar plum sweet jujubes sugar plum pudding
cupcake lollipop donut I love. Oat cake shortbread cake macaroon cookie I love soufflé oat cake. Cake pudding
cotton candy I love I love caramels soufflé.

Jelly beans fruitcake caramels sugar plum pie cotton candy fruitcake I love cotton candy. Jelly liquorice apple
pie pudding tiramisu dessert fruitcake donut sweet. I love dragée jelly-o chupa chups donut jelly beans. Tart I
love I love I love icing gummi bears soufflé donut. Jelly beans cheesecake ice cream jelly beans topping.
Macaroon cake jujubes I love I love topping. Bonbon bonbon cake chocolate cake cheesecake danish tiramisu
tiramisu liquorice. Soufflé oat cake gummies I love donut ice cream sweet roll. Candy canes cake pudding tootsie
roll I love gummi bears. Chupa chups chupa chups jelly beans chupa chups I love lemon drops. I love candy canes
carrot cake sesame snaps wafer lollipop I love jelly wafer. Candy pie soufflé I love cake sugar plum dessert
donut lollipop. Gingerbread I love marzipan bonbon pie. Carrot cake lollipop pie I love liquorice.

Toffee jujubes pudding cotton candy dessert I love. Biscuit cake fruitcake jelly-o candy pastry cupcake.
Fruitcake muffin jelly beans sweet roll topping dragée. Tootsie roll fruitcake bonbon soufflé croissant carrot
cake cake jujubes. Wafer fruitcake shortbread biscuit pie. Lemon drops gummi bears shortbread danish bonbon
dessert brownie cake. Cotton candy lemon drops gingerbread ice cream pastry macaroon I love lollipop. I love
muffin cake pudding jujubes muffin marshmallow candy. Marshmallow powder lemon drops jujubes cookie cotton candy
caramels macaroon. Biscuit cotton candy bonbon donut I love bear claw gummies chocolate cake. Brownie topping
cotton candy danish dessert muffin jelly sweet roll chocolate. Fruitcake bonbon jelly beans sweet roll cookie
biscuit chocolate jelly-o jujubes. Sweet dessert oat cake lemon drops donut candy canes dessert chocolate powder.

Jujubes apple pie marzipan jelly beans caramels icing. Jujubes carrot cake toffee jelly carrot cake sugar plum
cotton candy chocolate bar. I love jelly beans cotton candy toffee soufflé gummies I love biscuit. Tart dessert
soufflé tiramisu marzipan I love dessert caramels. Jelly-o gingerbread bonbon cupcake pie I love I love. Sweet
roll danish chocolate bar cake shortbread gummi bears. Dessert lemon drops fruitcake cotton candy I love apple
pie apple pie sweet roll. Candy canes jelly beans I love bonbon jelly cupcake croissant candy canes. Gingerbread
icing brownie pudding chocolate bar cotton candy. Pudding brownie pie candy chupa chups shortbread. Muffin
dessert I love I love powder. Marshmallow sesame snaps marshmallow brownie cake chupa chups. I love cake
macaroon ice cream shortbread jelly I love jelly beans cotton candy. Sesame snaps bonbon I love danish
cheesecake jujubes.

Jelly donut powder lemon drops shortbread. Oat cake marshmallow cake chupa chups chocolate halvah. Chocolate
cupcake jelly beans sugar plum macaroon chocolate bar pie cheesecake. Muffin marzipan fruitcake liquorice
brownie cake apple pie shortbread pudding. Sweet brownie chocolate topping fruitcake I love chupa chups apple
pie. Chocolate bar tiramisu cheesecake jujubes I love I love. Wafer croissant halvah pudding wafer caramels
lollipop. Tart tart gingerbread cupcake caramels toffee cookie. Macaroon candy canes candy canes jelly
marshmallow cake I love cake cake. Sweet candy shortbread pie caramels lollipop cupcake marshmallow shortbread.
Gummi bears caramels marshmallow tiramisu tootsie roll I love. Fruitcake sesame snaps sesame snaps sweet roll
gummies bear claw jelly beans.

Lollipop cupcake icing danish marshmallow jelly-o. Croissant chocolate cake pastry marshmallow marshmallow
fruitcake fruitcake chupa chups icing. I love jelly beans I love chocolate wafer sweet biscuit carrot cake I
love. I love jujubes caramels sweet roll soufflé chocolate. Dessert halvah gummies chocolate cake toffee danish
lollipop I love chocolate bar. Lemon drops macaroon jelly beans tiramisu apple pie chocolate bar. Cupcake icing
chocolate cake croissant marzipan. I love muffin dragée cheesecake chocolate fruitcake lemon drops brownie
pudding. Muffin soufflé chupa chups jelly chocolate gummies croissant halvah donut. I love soufflé sugar plum
pastry apple pie I love chocolate cake. Cupcake chocolate I love jelly I love dragée I love pie pie. I love cake
I love tart lollipop macaroon marshmallow gingerbread icing.

Pudding cake sweet marzipan croissant. Jelly tiramisu jujubes cake soufflé gummies. I love topping topping
soufflé tiramisu sweet roll candy ice cream danish. Gummi bears jujubes jelly-o cupcake pastry. Donut I love
cotton candy chocolate bar cheesecake. Marshmallow cotton candy chocolate I love dragée. Dragée caramels
liquorice lollipop gummi bears gingerbread toffee jelly-o. I love marzipan carrot cake sweet roll dragée cupcake
toffee gingerbread. Toffee gummi bears I love cotton candy cookie danish halvah cupcake. Oat cake I love soufflé
danish dessert. Chupa chups macaroon candy canes sweet I love bonbon macaroon. Bear claw jujubes I love cotton
candy I love oat cake bonbon.

Topping I love gummies tootsie roll I love marshmallow. Gingerbread cake oat cake pudding biscuit. Ice cream
donut wafer jelly-o chocolate I love. Icing toffee tart oat cake I love sugar plum sesame snaps pastry.
Gingerbread biscuit candy canes lollipop bear claw icing candy bear claw fruitcake. Oat cake danish cake
chocolate cake danish jujubes shortbread. Lollipop jujubes carrot cake croissant fruitcake marshmallow I
love icing cheesecake. Lemon drops carrot cake dessert oat cake carrot cake. Topping cupcake dragée chupa chups
cake dragée chocolate danish. Oat cake wafer bear claw cookie jujubes jujubes brownie soufflé. I love carrot
cake sweet roll macaroon cake gingerbread pastry wafer sweet roll. Pie ice cream cupcake candy canes cheesecake
icing wafer I love. Muffin dragée I love apple pie I love soufflé bear claw marzipan.

Topping powder jelly beans candy canes gummi bears. Dessert topping I love sweet I love. I love topping dessert
tart chocolate cake. Biscuit shortbread gummies cupcake bear claw. Marshmallow fruitcake sweet I love tiramisu
tiramisu cookie I love chupa chups. Sugar plum I love I love wafer jujubes muffin I love. Jelly-o carrot cake
fruitcake macaroon marzipan cake. Sesame snaps lollipop ice cream jelly-o pudding bear claw gummi bears I love.
Wafer croissant dragée wafer chocolate candy chocolate. Dessert pie gummi bears gummi bears carrot cake. Jelly
cupcake chocolate cake cake tiramisu croissant dragée. Candy fruitcake muffin gingerbread donut I love candy pie.

Halvah muffin oat cake marzipan apple pie cake marshmallow lemon drops. Marzipan croissant fruitcake lemon drops
bear claw lollipop bonbon lollipop. Sugar plum tiramisu soufflé I love shortbread carrot cake. Halvah jelly-o
icing sesame snaps I love powder cookie tootsie roll cheesecake. Jujubes ice cream dragée fruitcake cookie
carrot cake bonbon dragée wafer. Cheesecake I love I love sweet roll cake. Sugar plum toffee danish jelly-o
cheesecake soufflé cheesecake marzipan. Tart sugar plum icing macaroon pie cake cheesecake bear claw. Tootsie
roll muffin jelly chocolate cake wafer I love jelly shortbread. Sweet candy carrot cake chupa chups donut cake.
Dessert sugar plum cake pastry chocolate bar halvah pastry tiramisu. Ice cream cheesecake gummi bears candy I
love cupcake pie toffee candy canes.

Liquorice I love tiramisu marshmallow topping I love. Toffee sweet pudding icing cotton candy bonbon oat cake
carrot cake gummies. Candy toffee pudding sweet roll cotton candy lollipop powder lemon drops cake. Apple pie I
love chupa chups I love jujubes caramels. Jelly pie chocolate chocolate carrot cake cake. Toffee caramels muffin
cheesecake I love sweet roll tart. Croissant candy canes marzipan lemon drops cupcake sweet. I love I love
jelly-o donut cheesecake bear claw tart. Cheesecake icing jelly gummi bears macaroon. Sweet roll I love lollipop
cookie tart. Tiramisu tootsie roll sesame snaps croissant cookie halvah I love I love. Biscuit croissant powder
oat cake cake apple pie.

Topping oat cake pastry marshmallow gummi bears lemon drops bear claw soufflé pudding. Croissant biscuit
macaroon oat cake I love pastry. Pastry cake sugar plum macaroon chocolate cake dessert. I love cupcake sweet
roll sweet roll I love cheesecake. I love lemon drops halvah I love apple pie chocolate bar biscuit ice cream
topping. I love candy canes gingerbread caramels chupa chups cheesecake. I love jelly-o sesame snaps lemon drops
pastry toffee. Bonbon topping I love gummi bears dessert. Danish jelly I love marshmallow carrot cake. Dragée
macaroon dessert marshmallow jelly-o bear claw cotton candy sugar plum. Biscuit ice cream candy tart bear claw
candy I love brownie cotton candy. I love marshmallow lemon drops marshmallow I love candy canes wafer. Halvah
topping wafer cake danish I love I love I love. Chocolate cake carrot cake topping jelly lollipop I love I love
cotton candy I love.

Oat cake cotton candy cotton candy jujubes I love. Toffee topping cookie danish topping cheesecake. Cake bonbon
ice cream cake carrot cake icing cookie croissant. Cheesecake sesame snaps tiramisu lemon drops dessert pie.
Carrot cake sesame snaps shortbread muffin pie I love chocolate cake danish. Carrot cake cake jelly beans I love
toffee I love marzipan. Toffee lemon drops fruitcake I love cookie. Shortbread jujubes chupa chups jelly candy
bear claw chocolate. Pastry donut muffin fruitcake chocolate bar dessert cotton candy powder. Sweet roll chupa
chups dragée gummi bears ice cream tiramisu jujubes icing chocolate bar. I love lollipop I love oat cake apple
pie. Topping lemon drops donut fruitcake ice cream chupa chups. Dragée dragée fruitcake powder apple pie I love
donut.

Pie sugar plum bear claw candy canes wafer pastry. Cake caramels tootsie roll brownie cupcake croissant topping
sesame snaps. Topping oat cake sesame snaps jelly cupcake oat cake I love tootsie roll toffee. Jelly muffin
sugar plum danish sesame snaps. Liquorice chocolate bar marshmallow topping biscuit toffee carrot cake. Dragée
tart shortbread gummi bears apple pie. Tootsie roll tiramisu sugar plum marzipan chocolate cake. Cotton candy I
love I love pastry muffin fruitcake pie jelly-o I love. Topping marshmallow ice cream carrot cake chocolate.
Muffin dragée shortbread powder jelly. Chupa chups apple pie I love muffin pie sweet croissant. Chocolate bar
pastry cotton candy cotton candy dragée I love liquorice. Chocolate cake brownie marshmallow jelly-o jujubes
cookie sweet cookie candy. Shortbread I love cupcake powder soufflé tootsie roll jujubes.

Bear claw brownie tart caramels chupa chups I love candy canes biscuit. Biscuit bear claw tiramisu I love I love
macaroon dragée. Candy canes sweet roll powder jujubes donut cake topping cupcake. Biscuit carrot cake gummies
donut tart dragée cake fruitcake shortbread. Jelly-o chocolate cookie jelly chocolate pie sweet roll. Bear claw
I love marzipan croissant I love chocolate halvah liquorice. I love sweet carrot cake I love gingerbread. Pastry
muffin I love gummi bears I love I love marshmallow cupcake cookie. Marshmallow I love dragée cheesecake I love
candy canes. Shortbread cupcake jelly beans pie donut gummies sesame snaps. Bonbon soufflé chupa chups tiramisu
marshmallow macaroon brownie. Chupa chups bear claw carrot cake lemon drops icing. Cake caramels shortbread
gummies candy canes bonbon oat cake danish. Pastry brownie tiramisu candy canes oat cake tiramisu donut macaroon.

Tiramisu shortbread toffee I love sesame snaps wafer. Lemon drops ice cream dragée soufflé topping soufflé tart.
Bear claw pie chocolate cake chocolate apple pie marzipan. Oat cake candy canes brownie powder sugar plum. I
love pastry tootsie roll powder chocolate cake I love shortbread cake fruitcake. Candy cake dessert candy jelly
brownie I love sweet. Carrot cake carrot cake chocolate bar caramels biscuit gummi bears. Candy wafer pudding
gummies macaroon lollipop sugar plum bonbon. Brownie powder soufflé cupcake I love donut. Caramels gummies
shortbread muffin cake. Brownie wafer candy donut brownie. Icing cheesecake candy caramels cake muffin jelly.
Gummi bears I love jujubes I love candy canes shortbread. Chocolate caramels soufflé I love sweet.

Tart marshmallow powder I love I love dessert brownie I love gingerbread. Chocolate cake sweet roll soufflé
wafer powder cake cotton candy oat cake dragée. Brownie toffee muffin jelly-o bonbon bear claw soufflé carrot
cake. Jelly-o toffee pastry cheesecake jelly beans cookie I love tiramisu. Gingerbread pastry topping gummi
bears jelly. Brownie pie danish candy canes halvah. Powder lollipop jujubes sweet roll cake marzipan carrot cake
dessert cake. Apple pie I love pie tootsie roll wafer apple pie sweet. Pudding tiramisu croissant I love dessert
sugar plum candy canes I love wafer. Candy canes bonbon tart pie caramels chocolate I love oat cake shortbread.
Halvah I love croissant pie candy apple pie. Marshmallow apple pie macaroon dessert halvah.

I love chocolate fruitcake sesame snaps gingerbread wafer. Danish I love soufflé sweet cotton candy pudding.
Topping biscuit jelly beans cake liquorice dragée chocolate bar lemon drops. Chocolate bar jelly jelly I love
dragée chocolate cake halvah gummies. Candy canes pudding I love marzipan cheesecake powder jelly beans. Brownie
sweet pastry cotton candy tiramisu. Halvah fruitcake gummies cupcake donut topping dragée. Sugar plum marzipan I
love lemon drops dessert jelly donut. Cookie jujubes soufflé sugar plum croissant lollipop halvah. Brownie chupa
chups I love chupa chups chupa chups dragée. Marzipan tart donut topping soufflé tootsie roll toffee sesame
snaps. Donut danish muffin caramels gingerbread I love. I love I love croissant bonbon jelly beans jelly beans
chocolate caramels cheesecake. Gummi bears brownie toffee jelly biscuit candy apple pie.

I love chocolate cake donut I love jelly beans. Toffee marzipan shortbread jujubes sugar plum. Shortbread powder
cotton candy I love bonbon pudding biscuit halvah halvah. Tiramisu lollipop macaroon macaroon macaroon jelly-o
pastry pudding fruitcake. Donut brownie cookie icing jujubes icing bonbon fruitcake sesame snaps. Gingerbread
fruitcake tiramisu shortbread powder pastry dessert sweet roll marzipan. Liquorice jujubes I love chocolate cake
I love sweet cotton candy I love halvah. Shortbread gingerbread croissant icing biscuit. Chupa chups icing candy
canes lollipop jelly beans macaroon. Cupcake sweet topping carrot cake gummi bears jelly beans sesame snaps
icing. I love ice cream sweet pudding cheesecake. Dragée gummies gingerbread marzipan ice cream tart tiramisu. I
love chocolate bar sweet roll sweet roll I love tiramisu.

Jelly-o pastry candy marzipan donut cake. I love dessert liquorice caramels gummi bears donut lemon drops.
Fruitcake cupcake cupcake I love jujubes tart brownie chocolate. Jujubes topping lollipop candy canes topping
cotton candy halvah gummi bears topping. Danish pastry bear claw pudding pudding caramels. Gummies icing chupa
chups croissant I love chocolate halvah candy pastry. Oat cake jelly beans tart cake tart liquorice icing jelly
pie. Topping chocolate cupcake cotton candy cupcake cupcake. Cotton candy biscuit cookie chocolate bar gummies
gingerbread gummies. Lemon drops lemon drops I love chocolate cake cupcake soufflé gingerbread cake. Lemon drops
cotton candy jelly tart tiramisu caramels sweet marzipan. Powder wafer chocolate tootsie roll jelly gummi bears
dessert tootsie roll gummi bears. Icing macaroon biscuit I love cake chupa chups. Gummi bears dragée I love
candy canes I love gingerbread biscuit chocolate cake gummi bears.

Ice cream shortbread candy canes cotton candy marzipan cotton candy candy lollipop bear claw. Bear claw
shortbread toffee macaroon dragée tootsie roll dragée carrot cake I love. Topping dragée caramels danish
chocolate bar tart I love toffee apple pie. Marshmallow tootsie roll I love chocolate bar sweet icing chocolate
bar gummies. Sesame snaps I love pudding bonbon chocolate I love cotton candy sweet lollipop. Chocolate bar
sesame snaps I love cheesecake bear claw croissant candy. Jelly I love pudding wafer toffee. Pudding bonbon
dessert sweet cotton candy I love chocolate bar soufflé. Liquorice I love icing halvah shortbread cotton candy.
Pie sesame snaps I love tiramisu donut croissant. Brownie cotton candy donut lollipop wafer bonbon jelly-o candy
soufflé. Tootsie roll gummi bears cupcake macaroon apple pie candy canes I love. Marzipan pudding jelly beans
chocolate bar jelly-o I love. Wafer lollipop muffin I love shortbread.

Jelly beans topping halvah sweet sweet. Tootsie roll pie sesame snaps chocolate bar cake halvah cookie sesame
snaps. Brownie gummi bears gingerbread cheesecake tootsie roll I love donut. Bonbon jelly beans candy canes
gingerbread tiramisu. Cotton candy donut bear claw liquorice powder. Gummies cheesecake powder gummies tiramisu
brownie soufflé I love. Sweet cupcake soufflé I love cookie jujubes I love. Toffee soufflé cake halvah caramels
biscuit. Cotton candy lemon drops lemon drops marzipan danish apple pie cotton candy gummies. Icing gummi bears
jelly lemon drops I love. Halvah pie cake sweet tiramisu. Cupcake jujubes cake pie cheesecake. Chocolate I love
cookie muffin tart cake.

Brownie soufflé caramels jujubes candy canes biscuit tootsie roll. Fruitcake dessert icing chocolate bar jelly.
Macaroon pastry candy canes biscuit chupa chups liquorice halvah. Icing muffin jelly tart carrot cake dragée.
Oat cake carrot cake wafer I love brownie sugar plum icing. Caramels gingerbread pudding fruitcake I love gummi
bears I love. Lemon drops tart gummi bears jelly beans croissant chocolate cake danish gummies. Sugar plum I
love apple pie lemon drops liquorice. Topping liquorice muffin chocolate bar tart cotton candy gingerbread gummi
bears sweet. Gingerbread tiramisu I love shortbread cookie lemon drops. Tootsie roll cake I love halvah I love
muffin pie. Pastry bonbon macaroon donut cake apple pie jelly sweet roll. Tart chocolate bar marshmallow jelly
beans jujubes liquorice sugar plum.

Brownie cookie toffee sweet chocolate cake powder sugar plum chocolate bar toffee. Gummi bears danish I love
caramels cotton candy jelly beans gingerbread gingerbread dragée. Fruitcake wafer chupa chups jelly beans I love
sweet roll candy cupcake. Pie marshmallow gummi bears I love pudding pastry jelly chocolate cake ice cream.
Fruitcake apple pie cupcake I love toffee pie sesame snaps lollipop. Gingerbread lollipop pudding liquorice
carrot cake gummi bears powder pastry dessert. Apple pie cotton candy croissant pie jelly-o. Macaroon tart icing
toffee biscuit icing dessert sweet roll cotton candy. Jelly beans chocolate cake danish sweet I love jelly-o
brownie. I love cheesecake sesame snaps sweet jelly apple pie soufflé. Jelly beans chocolate cake cupcake
tiramisu marshmallow pastry icing ice cream. Biscuit gingerbread donut gummi bears caramels marzipan liquorice
lemon drops. Jelly beans cupcake I love pudding jelly candy biscuit.

I love chocolate donut lemon drops sweet roll. Donut chocolate tiramisu chupa chups biscuit I love. Jelly apple
pie chocolate bar dragée cake. I love macaroon chocolate caramels I love I love. Cupcake croissant halvah
gummies tart chocolate biscuit I love candy canes. I love fruitcake gummi bears chocolate cake I love carrot
cake apple pie. Apple pie marshmallow danish oat cake powder. Pie I love powder ice cream chocolate danish
macaroon sugar plum pie. I love chocolate cotton candy carrot cake carrot cake I love. Caramels dessert cake
marshmallow I love macaroon bonbon jelly beans. Dessert sugar plum I love oat cake I love wafer shortbread.
Sugar plum cheesecake cake chupa chups cotton candy caramels lemon drops.

Cake I love chocolate bar I love pudding pastry chocolate. Danish I love powder liquorice I love lemon drops.
Tootsie roll jelly cake cheesecake apple pie pie jelly-o. Dessert marshmallow topping I love brownie. Oat cake
fruitcake cookie croissant cake powder jelly fruitcake. Shortbread cake icing oat cake cupcake. Cake chocolate
cake I love I love gingerbread. Sweet roll oat cake I love pie carrot cake cake brownie cake caramels. Cookie
gummies I love gummies sesame snaps sweet roll apple pie I love. Pastry cake I love pie tart dessert lollipop
macaroon. Pastry icing marshmallow I love sesame snaps tiramisu cheesecake marzipan. Chupa chups chocolate icing
powder powder candy canes cake. Brownie shortbread candy canes topping sesame snaps I love. Jujubes sesame snaps
candy dessert danish soufflé dragée cookie I love.

Marshmallow pastry bear claw macaroon gummies caramels. Caramels pudding apple pie chupa chups lemon drops
liquorice pie I love. Powder macaroon pie carrot cake dragée. Soufflé cake jelly-o bear claw I love cotton candy
toffee jujubes I love. Carrot cake fruitcake cheesecake chocolate cake toffee powder. Tootsie roll bonbon I love
chocolate bar cake gingerbread. Halvah pastry I love croissant gummi bears macaroon jujubes bonbon. Brownie cake
tiramisu jujubes danish danish. Muffin chocolate bar cookie I love jelly powder brownie muffin. Candy canes
carrot cake carrot cake muffin sugar plum macaroon icing jelly. Donut powder gummi bears gingerbread oat cake
tart caramels pie cotton candy. Lollipop cotton candy jelly-o jelly beans chupa chups carrot cake tootsie roll
macaroon.

Brownie marshmallow ice cream cheesecake caramels oat cake danish. Sweet roll liquorice tootsie roll donut
cheesecake I love marzipan. Powder carrot cake topping muffin chocolate gingerbread. Gummi bears tiramisu bear
claw bear claw I love jujubes. Candy canes chocolate soufflé cotton candy jelly-o fruitcake oat cake toffee.
Muffin sweet roll cake cake tootsie roll icing brownie I love danish. Tart marshmallow marshmallow I love
marzipan sugar plum icing I love. I love chupa chups chocolate bar jelly beans soufflé jujubes gummies cake. I
love tart icing chocolate cake I love lollipop I love macaroon icing. I love chocolate fruitcake cake candy
canes lollipop sweet. Powder lollipop marzipan candy macaroon chupa chups pudding. Tootsie roll tart chocolate
bar carrot cake chocolate cake. Gingerbread ice cream tart oat cake cheesecake croissant. Jelly beans topping
brownie marzipan oat cake.

Candy canes pastry marshmallow muffin cookie fruitcake candy I love I love. Tootsie roll oat cake marzipan
cotton candy toffee carrot cake. Tiramisu marshmallow cheesecake I love I love candy cookie. Ice cream dragée
chocolate bar jelly carrot cake pie I love cupcake. Sesame snaps I love powder croissant I love oat cake.
Shortbread bonbon sugar plum jelly cake muffin I love jelly beans. Chocolate bar soufflé halvah I love danish I
love chocolate bar candy apple pie. Biscuit soufflé icing chocolate bar I love soufflé. Cake macaroon macaroon
powder cupcake cotton candy marzipan. Candy toffee cake icing fruitcake. Biscuit pie carrot cake soufflé brownie
marzipan. Sweet fruitcake pastry powder jelly beans. Chupa chups sweet oat cake muffin jelly-o. Dragée
gingerbread cookie cupcake muffin chupa chups sweet roll gummies chocolate bar.

I love dessert sesame snaps I love sweet roll danish. Oat cake dragée pudding pastry cake. Soufflé candy I love
I love croissant tiramisu croissant jelly beans. Bear claw biscuit tootsie roll oat cake pudding I love. Cake
chocolate cupcake lollipop powder donut pudding gummies. Pastry dessert donut croissant topping sugar plum cake
I love. Croissant cake fruitcake macaroon liquorice gummies sugar plum dragée chocolate bar. Tart pudding I love
chupa chups toffee pastry macaroon powder. Chupa chups chocolate bar oat cake biscuit muffin oat cake I love ice
cream. Toffee cotton candy pudding halvah gummi bears I love cookie I love. Halvah candy canes powder sweet
tootsie roll soufflé toffee. Sweet roll sweet biscuit liquorice tootsie roll cookie cotton candy cookie I love.

Lollipop fruitcake I love cake I love. Ice cream sugar plum macaroon bear claw chupa chups muffin gingerbread
muffin tootsie roll. Powder gummi bears wafer apple pie gummies bonbon macaroon. Tiramisu I love jelly-o sesame
snaps lemon drops I love shortbread lollipop. Ice cream sweet roll cookie caramels I love I love chocolate bar.
Shortbread I love shortbread bear claw I love. I love jelly beans topping marshmallow icing. Halvah sesame snaps
macaroon cake cheesecake. I love chocolate macaroon cupcake cupcake toffee bear claw chocolate. Macaroon biscuit
jelly beans dragée I love oat cake tart liquorice candy canes. Cookie brownie shortbread shortbread icing
tiramisu I love. Croissant gummies pastry I love danish donut. Sesame snaps ice cream cake candy jelly-o.

Croissant danish caramels pudding tiramisu sweet roll bonbon. Dessert cheesecake I love I love sweet muffin
croissant chupa chups donut. Tart danish chocolate bar cupcake lollipop muffin. Wafer cake jujubes cake cotton
candy. Cheesecake marshmallow soufflé sesame snaps dessert cake jelly soufflé. Dragée pastry oat cake biscuit
dessert jelly beans. Danish gingerbread pudding chocolate bar muffin liquorice cake. Tiramisu dragée lemon drops
biscuit carrot cake. Cake bonbon chocolate cake lemon drops apple pie candy canes. Tiramisu jelly beans gummi
bears sesame snaps wafer gingerbread gummies liquorice jelly. Marzipan chocolate cake liquorice caramels soufflé
lollipop jelly. Croissant sesame snaps cake marzipan chupa chups topping croissant.

Pie apple pie danish candy gingerbread. Jelly-o I love ice cream muffin gummi bears muffin chocolate. Macaroon
croissant candy canes chocolate bar candy cake sweet roll. Donut cotton candy apple pie cake cake pie dessert
brownie. Cake sweet soufflé jujubes tootsie roll I love I love carrot cake. Wafer jelly beans lollipop fruitcake
pudding pudding I love jujubes halvah. I love icing sweet roll danish gummies. I love I love chocolate cake
sweet roll oat cake I love gummi bears marshmallow gummies. Jelly-o chupa chups pie powder toffee. Lollipop
soufflé gingerbread sweet roll apple pie sweet gingerbread. Chocolate pudding toffee cotton candy apple pie
sugar plum lemon drops. Cotton candy soufflé fruitcake jelly-o I love marzipan tiramisu caramels lollipop.

Jelly-o croissant chupa chups lemon drops sesame snaps biscuit macaroon dessert fruitcake. Gummies bonbon I love
liquorice gummies lollipop. Cake powder sweet liquorice topping I love I love candy canes cheesecake. Sweet roll
pie croissant bonbon shortbread chocolate cake. Sesame snaps donut bonbon apple pie jelly beans marzipan chupa
chups tart sugar plum. Icing icing I love gummies candy canes topping. Tart pie brownie tiramisu macaroon
dragée. Chocolate macaroon marzipan I love sesame snaps jelly beans jujubes fruitcake. Marshmallow muffin
caramels candy brownie. Gummies I love lollipop pastry cupcake. Sweet roll tart marzipan ice cream I love I
love. I love pudding soufflé liquorice chupa chups muffin pie jujubes candy canes. Candy muffin I love oat cake
cupcake chocolate jelly-o.

Ice cream macaroon cake bonbon I love I love pie halvah icing. Gummies croissant sugar plum brownie gummi bears
I love I love sweet. Sugar plum cookie cotton candy I love sesame snaps. I love cheesecake cookie jujubes dragée
muffin. Chocolate cake biscuit lollipop jelly beans I love sugar plum jelly brownie. I love candy canes soufflé
I love muffin I love. Ice cream chupa chups chupa chups pastry dragée liquorice dessert lollipop. Cotton candy
soufflé jelly danish chocolate. Powder tiramisu danish cheesecake halvah cotton candy bear claw soufflé
marzipan. Donut donut I love dragée chocolate bar icing I love. Gummi bears lollipop tiramisu gingerbread
cupcake caramels. Sesame snaps cheesecake soufflé chocolate bar chocolate cake. Gummies marzipan pie chocolate
cake oat cake chupa chups chocolate bar.

Chocolate cake croissant fruitcake chupa chups gummi bears. Chocolate jujubes gummies wafer dessert fruitcake I
love chocolate cake pie. Gummies pastry chocolate bar chocolate cake pie gummi bears fruitcake candy. Sesame
snaps chupa chups gummies gummi bears wafer I love. Halvah cotton candy halvah chocolate cake sesame snaps.
Pudding gummies I love shortbread jelly-o oat cake I love danish caramels. Topping pastry caramels biscuit I
love caramels cake. Pastry fruitcake chupa chups sesame snaps chocolate I love lollipop. Lemon drops icing
chocolate cake I love jelly-o. I love dragée macaroon wafer shortbread. Tiramisu soufflé jelly-o jelly-o
chocolate cake chupa chups soufflé macaroon oat cake. Caramels cupcake topping apple pie chocolate cake dessert
chocolate cake. Shortbread jelly pastry sweet chocolate cookie chocolate bar marzipan.

Muffin fruitcake tart ice cream dessert jelly chupa chups biscuit cookie. Chocolate bar jelly beans cheesecake
candy chocolate bar powder sugar plum. Pudding tiramisu shortbread muffin wafer I love tootsie roll. Candy canes
liquorice toffee dessert sweet chocolate bar jelly beans pudding fruitcake. Marzipan cake I love dessert icing
gummi bears. Pastry caramels tootsie roll gummi bears topping candy dragée lollipop. Ice cream I love cake sugar
plum jelly candy sugar plum chocolate bar. Chocolate brownie fruitcake marzipan I love cake jujubes. Apple pie
toffee sugar plum chocolate cake. Sweet gummi bears topping pudding cookie shortbread toffee. Sugar plum
fruitcake dessert chupa chups macaroon tiramisu I love chocolate bar. Lemon drops chocolate bonbon apple pie
bonbon candy canes sugar plum fruitcake. Bonbon marzipan I love marzipan jelly beans I love marshmallow candy.

I love marzipan halvah jelly pudding cookie gingerbread icing chocolate cake. Sesame snaps sesame snaps gummies
bonbon wafer croissant icing. Chocolate danish topping sesame snaps chocolate caramels wafer chocolate cake.
Lollipop gingerbread halvah I love chocolate shortbread. Soufflé lemon drops bear claw sweet roll lollipop I
love cheesecake jelly beans. Cotton candy I love sweet roll candy sesame snaps sugar plum gingerbread.
Gingerbread fruitcake croissant sweet roll cookie sweet. Muffin cotton candy pie lollipop macaroon jelly
marzipan I love oat cake. Apple pie jelly muffin jujubes halvah wafer soufflé chocolate cake. Candy sugar plum I
love sesame snaps fruitcake powder cake I love danish. Soufflé candy canes marshmallow jelly-o cheesecake toffee
fruitcake I love. Soufflé jelly beans bonbon muffin marzipan sugar plum cupcake cake chupa chups. Tootsie roll
wafer gummi bears candy gummi bears marshmallow. Chupa chups gummi bears croissant ice cream powder jelly beans
candy canes I love dessert.
HEREDOC;
    }
}


class ClassAfterLongHereDoc
{
}
