<?php

namespace Foo;

/**
 * class VeryLongNowdoc { }
 */
class VeryLongNowdoc
{
    public function test_nowdoc()
    {
        return <<<'NOWDOC'
# I am the Doctor, and you are the Daleks!

Saving the world with meals on wheels. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister. Heh-haa! Super squeaky bum time! You hate me; you want to kill me! Well, go on! Kill me! KILL ME!

It's a fez. I wear a fez now. Fezes are cool. __You know how I sometimes have really brilliant ideas?__ *I'm the Doctor, I'm worse than everyone's aunt.* *catches himself* And that is not how I'm introducing myself.

## No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

I am the last of my species, and I know how that weighs on the heart so don't lie to me! You hate me; you want to kill me! Well, go on! Kill me! KILL ME! It's a fez. I wear a fez now. Fezes are cool. I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why.

1. Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you?
2. You've swallowed a planet!
3. You know how I sometimes have really brilliant ideas?

### Aw, you're all Mr. Grumpy Face today.

Sorry, checking all the water in this area; there's an escaped fish. Did I mention we have comfy chairs? I am the last of my species, and I know how that weighs on the heart so don't lie to me! Father Christmas. Santa Claus. Or as I've always known him: Jeff.

* It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!
* I'm the Doctor, I'm worse than everyone's aunt. *catches himself* And that is not how I'm introducing myself.
* Father Christmas. Santa Claus. Or as I've always known him: Jeff.

You hit me with a cricket bat. The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant.

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Heh-haa! Super squeaky bum time! You know when grown-ups tell you 'everything's going to be fine' and you think they're probably lying to make you feel better? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

You've swallowed a planet! No… It's a thing; it's like a plan, but with more greatness. I am the last of my species, and I know how that weighs on the heart so don't lie to me! *Insistently* Bow ties are cool! Come on Amy, I'm a normal bloke, tell me what normal blokes do!

I am the last of my species, and I know how that weighs on the heart so don't lie to me! No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? Stop talking, brain thinking. Hush.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? I hate yogurt. It's just stuff with bits in.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. You know how I sometimes have really brilliant ideas?

Father Christmas. Santa Claus. Or as I've always known him: Jeff. You've swallowed a planet! You hit me with a cricket bat. It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!

I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why. You hate me; you want to kill me! Well, go on! Kill me! KILL ME! You know how I sometimes have really brilliant ideas?

# I am the Doctor, and you are the Daleks!

Saving the world with meals on wheels. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister. Heh-haa! Super squeaky bum time! You hate me; you want to kill me! Well, go on! Kill me! KILL ME!

It's a fez. I wear a fez now. Fezes are cool. __You know how I sometimes have really brilliant ideas?__ *I'm the Doctor, I'm worse than everyone's aunt.* *catches himself* And that is not how I'm introducing myself.

## No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

I am the last of my species, and I know how that weighs on the heart so don't lie to me! You hate me; you want to kill me! Well, go on! Kill me! KILL ME! It's a fez. I wear a fez now. Fezes are cool. I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why.

1. Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you?
2. You've swallowed a planet!
3. You know how I sometimes have really brilliant ideas?

### Aw, you're all Mr. Grumpy Face today.

Sorry, checking all the water in this area; there's an escaped fish. Did I mention we have comfy chairs? I am the last of my species, and I know how that weighs on the heart so don't lie to me! Father Christmas. Santa Claus. Or as I've always known him: Jeff.

* It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!
* I'm the Doctor, I'm worse than everyone's aunt. *catches himself* And that is not how I'm introducing myself.
* Father Christmas. Santa Claus. Or as I've always known him: Jeff.

You hit me with a cricket bat. The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant.

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Heh-haa! Super squeaky bum time! You know when grown-ups tell you 'everything's going to be fine' and you think they're probably lying to make you feel better? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

You've swallowed a planet! No… It's a thing; it's like a plan, but with more greatness. I am the last of my species, and I know how that weighs on the heart so don't lie to me! *Insistently* Bow ties are cool! Come on Amy, I'm a normal bloke, tell me what normal blokes do!

I am the last of my species, and I know how that weighs on the heart so don't lie to me! No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? Stop talking, brain thinking. Hush.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? I hate yogurt. It's just stuff with bits in.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. You know how I sometimes have really brilliant ideas?

Father Christmas. Santa Claus. Or as I've always known him: Jeff. You've swallowed a planet! You hit me with a cricket bat. It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!

I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why. You hate me; you want to kill me! Well, go on! Kill me! KILL ME! You know how I sometimes have really brilliant ideas?


# I am the Doctor, and you are the Daleks!

Saving the world with meals on wheels. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister. Heh-haa! Super squeaky bum time! You hate me; you want to kill me! Well, go on! Kill me! KILL ME!

It's a fez. I wear a fez now. Fezes are cool. __You know how I sometimes have really brilliant ideas?__ *I'm the Doctor, I'm worse than everyone's aunt.* *catches himself* And that is not how I'm introducing myself.

## No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

I am the last of my species, and I know how that weighs on the heart so don't lie to me! You hate me; you want to kill me! Well, go on! Kill me! KILL ME! It's a fez. I wear a fez now. Fezes are cool. I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why.

1. Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you?
2. You've swallowed a planet!
3. You know how I sometimes have really brilliant ideas?

### Aw, you're all Mr. Grumpy Face today.

Sorry, checking all the water in this area; there's an escaped fish. Did I mention we have comfy chairs? I am the last of my species, and I know how that weighs on the heart so don't lie to me! Father Christmas. Santa Claus. Or as I've always known him: Jeff.

* It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!
* I'm the Doctor, I'm worse than everyone's aunt. *catches himself* And that is not how I'm introducing myself.
* Father Christmas. Santa Claus. Or as I've always known him: Jeff.

You hit me with a cricket bat. The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant.

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Heh-haa! Super squeaky bum time! You know when grown-ups tell you 'everything's going to be fine' and you think they're probably lying to make you feel better? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

You've swallowed a planet! No… It's a thing; it's like a plan, but with more greatness. I am the last of my species, and I know how that weighs on the heart so don't lie to me! *Insistently* Bow ties are cool! Come on Amy, I'm a normal bloke, tell me what normal blokes do!

I am the last of my species, and I know how that weighs on the heart so don't lie to me! No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? Stop talking, brain thinking. Hush.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? I hate yogurt. It's just stuff with bits in.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. You know how I sometimes have really brilliant ideas?

Father Christmas. Santa Claus. Or as I've always known him: Jeff. You've swallowed a planet! You hit me with a cricket bat. It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!

I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why. You hate me; you want to kill me! Well, go on! Kill me! KILL ME! You know how I sometimes have really brilliant ideas?


# I am the Doctor, and you are the Daleks!

Saving the world with meals on wheels. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister. Heh-haa! Super squeaky bum time! You hate me; you want to kill me! Well, go on! Kill me! KILL ME!

It's a fez. I wear a fez now. Fezes are cool. __You know how I sometimes have really brilliant ideas?__ *I'm the Doctor, I'm worse than everyone's aunt.* *catches himself* And that is not how I'm introducing myself.

## No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

I am the last of my species, and I know how that weighs on the heart so don't lie to me! You hate me; you want to kill me! Well, go on! Kill me! KILL ME! It's a fez. I wear a fez now. Fezes are cool. I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why.

1. Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you?
2. You've swallowed a planet!
3. You know how I sometimes have really brilliant ideas?

### Aw, you're all Mr. Grumpy Face today.

Sorry, checking all the water in this area; there's an escaped fish. Did I mention we have comfy chairs? I am the last of my species, and I know how that weighs on the heart so don't lie to me! Father Christmas. Santa Claus. Or as I've always known him: Jeff.

* It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!
* I'm the Doctor, I'm worse than everyone's aunt. *catches himself* And that is not how I'm introducing myself.
* Father Christmas. Santa Claus. Or as I've always known him: Jeff.

You hit me with a cricket bat. The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant.

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Heh-haa! Super squeaky bum time! You know when grown-ups tell you 'everything's going to be fine' and you think they're probably lying to make you feel better? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

You've swallowed a planet! No… It's a thing; it's like a plan, but with more greatness. I am the last of my species, and I know how that weighs on the heart so don't lie to me! *Insistently* Bow ties are cool! Come on Amy, I'm a normal bloke, tell me what normal blokes do!

I am the last of my species, and I know how that weighs on the heart so don't lie to me! No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? Stop talking, brain thinking. Hush.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? I hate yogurt. It's just stuff with bits in.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. You know how I sometimes have really brilliant ideas?

Father Christmas. Santa Claus. Or as I've always known him: Jeff. You've swallowed a planet! You hit me with a cricket bat. It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!

I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why. You hate me; you want to kill me! Well, go on! Kill me! KILL ME! You know how I sometimes have really brilliant ideas?


# I am the Doctor, and you are the Daleks!

Saving the world with meals on wheels. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister. Heh-haa! Super squeaky bum time! You hate me; you want to kill me! Well, go on! Kill me! KILL ME!

It's a fez. I wear a fez now. Fezes are cool. __You know how I sometimes have really brilliant ideas?__ *I'm the Doctor, I'm worse than everyone's aunt.* *catches himself* And that is not how I'm introducing myself.

## No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

I am the last of my species, and I know how that weighs on the heart so don't lie to me! You hate me; you want to kill me! Well, go on! Kill me! KILL ME! It's a fez. I wear a fez now. Fezes are cool. I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why.

1. Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you?
2. You've swallowed a planet!
3. You know how I sometimes have really brilliant ideas?

### Aw, you're all Mr. Grumpy Face today.

Sorry, checking all the water in this area; there's an escaped fish. Did I mention we have comfy chairs? I am the last of my species, and I know how that weighs on the heart so don't lie to me! Father Christmas. Santa Claus. Or as I've always known him: Jeff.

* It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!
* I'm the Doctor, I'm worse than everyone's aunt. *catches himself* And that is not how I'm introducing myself.
* Father Christmas. Santa Claus. Or as I've always known him: Jeff.

You hit me with a cricket bat. The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant.

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Heh-haa! Super squeaky bum time! You know when grown-ups tell you 'everything's going to be fine' and you think they're probably lying to make you feel better? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

You've swallowed a planet! No… It's a thing; it's like a plan, but with more greatness. I am the last of my species, and I know how that weighs on the heart so don't lie to me! *Insistently* Bow ties are cool! Come on Amy, I'm a normal bloke, tell me what normal blokes do!

I am the last of my species, and I know how that weighs on the heart so don't lie to me! No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? Stop talking, brain thinking. Hush.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? I hate yogurt. It's just stuff with bits in.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. You know how I sometimes have really brilliant ideas?

Father Christmas. Santa Claus. Or as I've always known him: Jeff. You've swallowed a planet! You hit me with a cricket bat. It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!

I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why. You hate me; you want to kill me! Well, go on! Kill me! KILL ME! You know how I sometimes have really brilliant ideas?


# I am the Doctor, and you are the Daleks!

Saving the world with meals on wheels. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister. Heh-haa! Super squeaky bum time! You hate me; you want to kill me! Well, go on! Kill me! KILL ME!

It's a fez. I wear a fez now. Fezes are cool. __You know how I sometimes have really brilliant ideas?__ *I'm the Doctor, I'm worse than everyone's aunt.* *catches himself* And that is not how I'm introducing myself.

## No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

I am the last of my species, and I know how that weighs on the heart so don't lie to me! You hate me; you want to kill me! Well, go on! Kill me! KILL ME! It's a fez. I wear a fez now. Fezes are cool. I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why.

1. Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you?
2. You've swallowed a planet!
3. You know how I sometimes have really brilliant ideas?

### Aw, you're all Mr. Grumpy Face today.

Sorry, checking all the water in this area; there's an escaped fish. Did I mention we have comfy chairs? I am the last of my species, and I know how that weighs on the heart so don't lie to me! Father Christmas. Santa Claus. Or as I've always known him: Jeff.

* It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!
* I'm the Doctor, I'm worse than everyone's aunt. *catches himself* And that is not how I'm introducing myself.
* Father Christmas. Santa Claus. Or as I've always known him: Jeff.

You hit me with a cricket bat. The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant.

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Heh-haa! Super squeaky bum time! You know when grown-ups tell you 'everything's going to be fine' and you think they're probably lying to make you feel better? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

You've swallowed a planet! No… It's a thing; it's like a plan, but with more greatness. I am the last of my species, and I know how that weighs on the heart so don't lie to me! *Insistently* Bow ties are cool! Come on Amy, I'm a normal bloke, tell me what normal blokes do!

I am the last of my species, and I know how that weighs on the heart so don't lie to me! No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? Stop talking, brain thinking. Hush.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? I hate yogurt. It's just stuff with bits in.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. You know how I sometimes have really brilliant ideas?

Father Christmas. Santa Claus. Or as I've always known him: Jeff. You've swallowed a planet! You hit me with a cricket bat. It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!

I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why. You hate me; you want to kill me! Well, go on! Kill me! KILL ME! You know how I sometimes have really brilliant ideas?

# I am the Doctor, and you are the Daleks!

Saving the world with meals on wheels. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister. Heh-haa! Super squeaky bum time! You hate me; you want to kill me! Well, go on! Kill me! KILL ME!

It's a fez. I wear a fez now. Fezes are cool. __You know how I sometimes have really brilliant ideas?__ *I'm the Doctor, I'm worse than everyone's aunt.* *catches himself* And that is not how I'm introducing myself.

## No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

I am the last of my species, and I know how that weighs on the heart so don't lie to me! You hate me; you want to kill me! Well, go on! Kill me! KILL ME! It's a fez. I wear a fez now. Fezes are cool. I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why.

1. Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you?
2. You've swallowed a planet!
3. You know how I sometimes have really brilliant ideas?

### Aw, you're all Mr. Grumpy Face today.

Sorry, checking all the water in this area; there's an escaped fish. Did I mention we have comfy chairs? I am the last of my species, and I know how that weighs on the heart so don't lie to me! Father Christmas. Santa Claus. Or as I've always known him: Jeff.

* It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!
* I'm the Doctor, I'm worse than everyone's aunt. *catches himself* And that is not how I'm introducing myself.
* Father Christmas. Santa Claus. Or as I've always known him: Jeff.

You hit me with a cricket bat. The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant.

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Heh-haa! Super squeaky bum time! You know when grown-ups tell you 'everything's going to be fine' and you think they're probably lying to make you feel better? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

You've swallowed a planet! No… It's a thing; it's like a plan, but with more greatness. I am the last of my species, and I know how that weighs on the heart so don't lie to me! *Insistently* Bow ties are cool! Come on Amy, I'm a normal bloke, tell me what normal blokes do!

I am the last of my species, and I know how that weighs on the heart so don't lie to me! No, I'll fix it. I'm good at fixing rot. Call me the Rotmeister. No, I'm the Doctor. Don't call me the Rotmeister.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? Stop talking, brain thinking. Hush.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? I hate yogurt. It's just stuff with bits in.

Annihilate? No. No violence. I won't stand for it. Not now, not ever, do you understand me?! I'm the Doctor, the Oncoming Storm - and you basically meant beat them in a football match, didn't you? All I've got to do is pass as an ordinary human being. Simple. What could possibly go wrong?

The way I see it, every life is a pile of good things and bad things.…hey.…the good things don't always soften the bad things; but vice-versa the bad things don't necessarily spoil the good things and make them unimportant. You know how I sometimes have really brilliant ideas?

Father Christmas. Santa Claus. Or as I've always known him: Jeff. You've swallowed a planet! You hit me with a cricket bat. It's art! A statement on modern society, 'Oh Ain't Modern Society Awful?'!

I'm the Doctor. Well, they call me the Doctor. I don't know why. I call me the Doctor too. I still don't know why. You hate me; you want to kill me! Well, go on! Kill me! KILL ME! You know how I sometimes have really brilliant ideas?

NOWDOC;
    }
}
