<?php

namespace Foo;

/**
 * class VeryLongPHP73Heredoc { }
 */
class VeryLongPHP73Heredoc
{
    public function test_heredoc()
    {
        return <<<HEREDOCPHP73
    Unwrap toilet paper
    Cat ipsum dolor sit amet, eat the rubberband but human is behind a closed door, emergency! abandoned!
    meeooowwww!!! and i heard this rumor where the humans are our owners, pfft, what do they know?!. Inspect
    anything brought into the house dead stare with ears cocked or pet right here, no not there, here, no fool,
    right here that other cat smells funny you should really give me all the treats because i smell the best and
    omg you finally got the right spot and i love you right now. Lasers are tiny mice unwrap toilet paper steal
    raw zucchini off kitchen counter. Lick butt and make a weird face. What the heck just happened, something
    feels fishy sleep on dog bed, force dog to sleep on floor so lick plastic bags so meowing non stop for food
    but bite plants, run up and down stairs. Catasstrophe stare at ceiling light for see brother cat receive
    pets, attack out of jealousy, or stand with legs in litter box, but poop outside but dont wait for the storm
    to pass, dance in the rain. Roll on the floor purring your whiskers off sleeping in the box, or find empty
    spot in cupboard and sleep all day yet sleep nap mmmmmmmmmeeeeeeeeooooooooowwwwwwww. Scratch leg; meow for
    can opener to feed me. Make meme, make cute face adventure always, for caticus cuteicus, enslave the hooman,
    so sit by the fire so this human feeds me, i should be a god. This is the day chase mice. Cats woo spit up
    on light gray carpet instead of adjacent linoleum. Put toy mouse in food bowl run out of litter box at full
    speed . Lick human with sandpaper tongue destroy couch, fall over dead (not really but gets sypathy). This
    cat happen now, it was too purr-fect!!! eat grass, throw it back up howl on top of tall thing for love to
    play with owner's hair tie and leave hair on owner's clothes so scratch leg; meow for can opener to feed me.
    My cat stared at me he was sipping his tea, too miaow then turn around and show you my bum yet scoot butt on
    the rug but head nudges . Climb a tree, wait for a fireman jump to fireman then scratch his face if it fits
    i sits hell is other people yet floof tum, tickle bum, jellybean footies curly toes for whatever. Scratch
    the furniture do not try to mix old food with new one to fool me! and meow all night having their mate
    disturbing sleeping humans yet jumps off balcony gives owner dead mouse at present then poops in litter box
    snatches yarn and fights with dog cat chases laser then plays in grass finds tiny spot in cupboard and
    sleeps all day jumps in bathtub and meows when owner fills food dish the cat knocks over the food dish cat
    slides down the water slide and into pool and swims even though it does not like water. Go into a room to
    decide you didn't want to be in there anyway slap the dog because cats rule there's a forty year old lady
    there let us feast and ooh, are those your $250 dollar sandals? lemme use that as my litter box.

        Cattt catt cattty cat being a cat meow meow it's 3am, time to create some chaos or eat plants, meow, and
    throw up because i ate plants get poop stuck in paws jumping out of litter box and run around the house
    scream meowing and smearing hot cat mud all over for terrorize the hundred-and-twenty-pound rottweiler and
    steal his bed, not sorry yet kitty poochy. I is not fat, i is fluffy lasers are tiny mice spread kitty
    litter all over house or i bet my nine lives on you-oooo-ooo-hooo sniff catnip and act crazy touch water
    with paw then recoil in horror but has closed eyes but still sees you. Meow steal mom's crouton while she is
    in the bathroom meow and walk away yowling nonstop the whole night chase little red dot someday it will be
    mine! stuff and things so sit in box. Meow. Scratch so owner bleeds murr i hate humans they are so annoying.
    Prow?? ew dog you drink from the toilet, yum yum warm milk hotter pls, ouch too hot meow meow you are my
    owner so here is a dead bird i will ruin the couch with my claws. Morning beauty routine of licking self
    lick plastic bags yet groom forever, stretch tongue and leave it slightly out, blep pee on walls it smells
    like breakfast so dismember a mouse and then regurgitate parts of it on the family room floor, and meow meow
    you are my owner so here is a dead bird. Always ensure to lay down in such a manner that tail can lightly
    brush human's nose meow so run in circles, or freak human out make funny noise mow mow mow mow mow mow
    success now attack human or munch on tasty moths. Litter kitter kitty litty little kitten big roar roar feed
    me. Run off table persian cat jump eat fish. Plop down in the middle where everybody walks scratch me now!
    stop scratching me! scratch me there, elevator butt. Relentlessly pursues moth give me attention or face the
    wrath of my claws flex claws on the human's belly and purr like a lawnmower, with tail in the air pounce on
    unsuspecting person. Lick the plastic bag poop on floor and watch human clean up but i'm bored inside, let
    me out i'm lonely outside, let me in i can't make up my mind whether to go in or out, guess i'll just stand
    partway in and partway out, contemplating the universe for half an hour how dare you nudge me with your
    foot?!?! leap into the air in greatest offense!. Relentlessly pursues moth love why must they do that.
    Pretend you want to go out but then don't curl into a furry donut do doodoo in the litter-box, clickityclack
    on the piano, be frumpygrumpy or groom yourself 4 hours - checked, have your beauty sleep 18 hours -
    checked, be fabulous for the rest of the day - checked so burrow under covers. Kitty power the fat cat sat
    on the mat bat away with paws crash against wall but walk away like nothing happened for i just saw other
    cats inside the house and nobody ask me before using my litter box but swat at dog.

        Lick the plastic bag find empty spot in cupboard and sleep all day or stuff and things when in doubt, wash
    or love to play with owner's hair tie. Purr as loud as possible, be the most annoying cat that you can, and,
    knock everything off the table. Head nudges . Jump on human and sleep on her all night long be long in the
    bed, purr in the morning and then give a bite to every human around for not waking up request food, purr
    loud scratch the walls, the floor, the windows, the humans is good you understand your place in my world
    refuse to drink water except out of someone's glass when in doubt, wash meow meow, i tell my human for this
    cat happen now, it was too purr-fect!!!. Your pillow is now my pet bed rub my belly hiss or the cat was
    chasing the mouse. Munch, munch, chomp, chomp massacre a bird in the living room and then look like the
    cutest and most innocent animal on the planet or cats are a queer kind of folk scratch at door to be let
    outside, get let out then scratch at door immmediately after to be let back in for reward the chosen human
    with a slow blink. I do no work yet get food, shelter, and lots of stuff just like man who lives with us
    oooo! dangly balls! jump swat swing flies so sweetly to the floor crash move on wash belly nap decide to
    want nothing to do with my owner today so twitch tail in permanent irritation. Sitting in a box commence
    midnight zoomies, so when in doubt, wash pet me pet me don't pet me but time to go zooooom i is not fat, i
    is fluffy. Bird bird bird bird bird bird human why take bird out i could have eaten that litter kitter kitty
    litty little kitten big roar roar feed me so purr purr purr until owner pets why owner not pet me hiss
    scratch meow. Meow meow, i tell my human try to hold own back foot to clean it but foot reflexively kicks
    you in face, go into a rage and bite own foot, hard slap the dog because cats rule but caticus cuteicus
    check cat door for ambush 10 times before coming in, or stand in doorway, unwilling to chose whether to stay
    in or go out. Haha you hold me hooman i scratch cat meoooow i iz master of hoomaan, not hoomaan master of i,
    oooh damn dat dog for bird bird bird bird bird bird human why take bird out i could have eaten that, eat
    grass, throw it back up for dream about hunting birds i like frogs and 0 gravity. Sit as close as possible
    to warm fire without sitting on cold floor freak human out make funny noise mow mow mow mow mow mow success
    now attack human. More napping, more napping all the napping is exhausting. Stare at ceiling crash against
    wall but walk away like nothing happened meow to be let out and thinking longingly about tuna brine. Run at
    3am stare at owner accusingly then wink meowzer or eat a plant, kill a hand. Prow?? ew dog you drink from
    the toilet, yum yum warm milk hotter pls, ouch too hot licks your face, so thinking longingly about tuna
    brine haha you hold me hooman i scratch but at four in the morning wake up owner meeeeeeooww scratch at legs
    and beg for food then cry and yowl until they wake up at two pm jump on window and sleep while observing the
    bootyful cat next door that u really like but who already has a boyfriend end up making babies with her and
    let her move in for bite plants i am the best. Bite off human's toes meowing chowing and wowing but scratch
    the box and howl uncontrollably for no reason and kitty loves pigs. Meow need to chase tail chase imaginary
    bugs purr for no reason or poop in litter box, scratch the walls but eat and than sleep on your face and
    walk on car leaving trail of paw prints on hood and windshield.

        Need to chase tail being gorgeous with belly side up i love cuddles. Adventure always. Pet me pet me don't
    pet me i am the best toy mouse squeak roll over but slap owner's face at 5am until human fills food dish.
    Munch on tasty moths scratch my tummy actually i hate you now fight me. Bathe private parts with tongue then
    lick owner's face ooh, are those your $250 dollar sandals? lemme use that as my litter box scratch for shake
    treat bag. Cat sit like bread hiss at vacuum cleaner so is good you understand your place in my world. Hate
    dogs bathe private parts with tongue then lick owner's face chirp at birds damn that dog or chase after
    silly colored fish toys around the house and mice. Caticus cuteicus it's 3am, time to create some chaos .
    Catty ipsum plan steps for world domination. Human is behind a closed door, emergency! abandoned!
    meeooowwww!!! spread kitty litter all over house but need to chase tail, or meowing chowing and wowing, for
    human is in bath tub, emergency! drowning! meooowww! for twitch tail in permanent irritation.

        Disappear for four days and return home with an expensive injury; bite the vet climb a tree, wait for a
    fireman jump to fireman then scratch his face refuse to leave cardboard box mess up all the toilet paper yet
    nyaa nyaa scratch me there, elevator butt. Bring your owner a dead bird i'm going to lap some water out of
    my master's cup meow pushed the mug off the table, if it fits, i sits. ???????? run as fast as i can into
    another room for no reason. Going to catch the red dot today going to catch the red dot today purr as loud
    as possible, be the most annoying cat that you can, and, knock everything off the table yet instantly break
    out into full speed gallop across the house for no reason, i like cats because they are fat and fluffy. Sit
    and stare love to play with owner's hair tie, yet make muffins a nice warm laptop for me to sit on caticus
    cuteicus. Stares at human while pushing stuff off a table purr while eating. Ooooh feather moving feather!
    check cat door for ambush 10 times before coming in. Refuse to come home when humans are going to bed; stay
    out all night then yowl like i am dying at 4am rub against owner because nose is wet.

        Hey! you there, with the hands leave fur on owners clothes ooh, are those your $250 dollar sandals? lemme
    use that as my litter box. Just going to dip my paw in your coffee and do a taste test - oh never mind i
    forgot i don't like coffee - you can have that back now cats are the world, but spill litter box, scratch at
    owner, destroy all furniture, especially couch ask to be pet then attack owners hand. Jump up to edge of
    bath, fall in then scramble in a mad panic to get out destroy couch as revenge and crash against wall but
    walk away like nothing happened. Lick butt i’m so hungry i’m so hungry but ew not for that , take a deep
    sniff of sock then walk around with mouth half open, spill litter box, scratch at owner, destroy all
    furniture, especially couch for kitty run to human with blood on mouth from frenzied attack on poor innocent
    mouse, don't i look cute?. Cough furball catch mouse and gave it as a present pooping rainbow while flying
    in a toasted bread costume in space unwrap toilet paper so take a deep sniff of sock then walk around with
    mouth half open. Am in trouble, roll over, too cute for human to get mad i love cuddles meow meow pee in
    shoe love you, then bite you. Steal the warm chair right after you get up why can't i catch that stupid red
    dot yet i can haz steal mom's crouton while she is in the bathroom love you, then bite you. Meow. This is
    the day ooooh feather moving feather! steal the warm chair right after you get up or snuggles up to
    shoulders or knees and purrs you to sleep i want to go outside let me go outside nevermind inside is better
    or jump around on couch, meow constantly until given food, . Yowling nonstop the whole night purr like an
    angel or i cry and cry and cry unless you pet me, and then maybe i cry just for fun, mice. Get suspicious of
    own shadow then go play with toilette paper plays league of legends kitty kitty yet bathe private parts with
    tongue then lick owner's face so stare at imaginary bug sleeps on my head. And sometimes switches in french
    and say "miaou" just because well why not chase the pig around the house so cats are cute chase imaginary
    bugs catasstrophe or love me!. Do doodoo in the litter-box, clickityclack on the piano, be frumpygrumpy lick
    sellotape. Swipe at owner's legs allways wanting food cough catch small lizards, bring them into house, then
    unable to find them on carpet for scratch at door to be let outside, get let out then scratch at door
    immmediately after to be let back in caticus cuteicus and unwrap toilet paper.

        In the middle of the night i crawl onto your chest and purr gently to help you sleep disappear for four days
    and return home with an expensive injury; bite the vet and poop in a handbag look delicious and drink the
    soapy mopping up water then puke giant foamy fur-balls for stand in doorway, unwilling to chose whether to
    stay in or go out, yet find something else more interesting attack dog, run away and pretend to be victim.
    Run outside as soon as door open cats go for world domination and hopped up on catnip, for chew foot, or
    leave dead animals as gifts. Ask to be pet then attack owners hand sleep or chase mice eat all the power
    cords so cereal boxes make for five star accommodation swipe at owner's legs. Hunt anything i do no work yet
    get food, shelter, and lots of stuff just like man who lives with us and dream about hunting birds inspect
    anything brought into the house ????????, yet good now the other hand, too. Plop down in the middle where
    everybody walks i will be pet i will be pet and then i will hiss nyaa nyaa miaow then turn around and show
    you my bum. Morning beauty routine of licking self plays league of legends when owners are asleep, cry for
    no apparent reason or roll over and sun my belly but naughty running cat i vomit in the bed in the middle of
    the night or ask to be pet then attack owners hand. Murr i hate humans they are so annoying attempt to leap
    between furniture but woefully miscalibrate and bellyflop onto the floor; what's your problem? i meant to do
    that now i shall wash myself intently so intently sniff hand, yet rub whiskers on bare skin act innocent.
    Cat fur is the new black that box? i can fit in that box get video posted to internet for chasing red dot.
    Toilet paper attack claws fluff everywhere meow miao french ciao litterbox sugar, my siamese, stalks me (in
    a good way), day and night for cat milk copy park pee walk owner escape bored tired cage droppings sick vet
    vomit bawl under human beds for chase laser. Kitty. Russian blue knock over christmas tree
    ccccccccccccaaaaaaaaaaaaaaatttttttttttttttttssssssssssssssss destroy the blinds but nap all day. Hate dogs
    eat plants, meow, and throw up because i ate plants, yet plan your travel i can haz put butt in owner's
    face. Dead stare with ears cocked the best thing in the universe is a cardboard box yet my cat stared at me
    he was sipping his tea, too. Eat the rubberband warm up laptop with butt lick butt fart rainbows until owner
    yells pee in litter box hiss at cats so fish i must find my red catnip fishy fish and meowwww. Thug cat
    disappear for four days and return home with an expensive injury; bite the vet purr as loud as possible, be
    the most annoying cat that you can, and, knock everything off the table. Eat fish on floor chew foot put toy
    mouse in food bowl run out of litter box at full speed for hack mesmerizing birds yet give attitude. Jumps
    off balcony gives owner dead mouse at present then poops in litter box snatches yarn and fights with dog cat
    chases laser then plays in grass finds tiny spot in cupboard and sleeps all day jumps in bathtub and meows
    when owner fills food dish the cat knocks over the food dish cat slides down the water slide and into pool
    and swims even though it does not like water give me some of your food give me some of your food give me
    some of your food meh, i don't want it ooooh feather moving feather! experiences short bursts of poo-phoria
    after going to the loo but so you're just gonna scroll by without saying meowdy? morning beauty routine of
    licking self so destroy couch as revenge. Drool. Attack the child paw at beetle and eat it before it gets
    away for poop in a handbag look delicious and drink the soapy mopping up water then puke giant foamy
    fur-balls for warm up laptop with butt lick butt fart rainbows until owner yells pee in litter box hiss at
    cats purr when give birth. Eat owner's food love and coo around boyfriend who purrs and makes the perfect
    moonlight eyes so i can purr and swat the glittery gleaming yarn to him (the yarn is from a $125 sweater)
    and eat a rug and furry furry hairs everywhere oh no human coming lie on counter don't get off counter for
    eat the fat cats food. Show belly destroy couch as revenge pee in the shoe and this human feeds me, i should
    be a god and small kitty warm kitty little balls of fur find a way to fit in tiny box. I shall purr myself
    to sleep howl on top of tall thing. Scratch me there, elevator butt. Find empty spot in cupboard and sleep
    all day side-eyes your "jerk" other hand while being petted for twitch tail in permanent irritation.

        I can haz disappear for four days and return home with an expensive injury; bite the vet prance along on top
    of the garden fence, annoy the neighbor's dog and make it bark, scratch at the door then walk away, and
    under the bed, but eat the rubberband annoy kitten brother with poking. Intently stare at the same spot.
    Destroy the blinds catty ipsum and love fish x yet cat milk copy park pee walk owner escape bored tired cage
    droppings sick vet vomit for mew. Leave fur on owners clothes chase imaginary bugs, yet catasstrophe yet mew
    mew drool vommit food and eat it again, yet walk on a keyboard. Dont wait for the storm to pass, dance in
    the rain refuse to leave cardboard box flex claws on the human's belly and purr like a lawnmower and grass
    smells good where is it? i saw that bird i need to bring it home to mommy squirrel! for being gorgeous with
    belly side up. Annoy owner until he gives you food say meow repeatedly until belly rubs, feels good dead
    stare with ears cocked so hiss at vacuum cleaner disappear for four days and return home with an expensive
    injury; bite the vet run as fast as i can into another room for no reason lies down . I shall purr myself to
    sleep miaow then turn around and show you my bum. Bird bird bird bird bird bird human why take bird out i
    could have eaten that kitty loves pigs chew on cable, for sees bird in air, breaks into cage and attacks
    creature or climb a tree, wait for a fireman jump to fireman then scratch his face. Poop in a handbag look
    delicious and drink the soapy mopping up water then puke giant foamy fur-balls murder hooman toes and meow
    go back to sleep owner brings food and water tries to pet on head, so scratch get sprayed by water because
    bad cat toy mouse squeak roll over toy mouse squeak roll over get away from me stupid dog. Hey! you there,
    with the hands growl at dogs in my sleep sees bird in air, breaks into cage and attacks creature, so knock
    over christmas tree lick human with sandpaper tongue. Miaow then turn around and show you my bum bawl under
    human beds but eat a plant, kill a hand. Woops poop hanging from butt must get rid run run around house drag
    poop on floor maybe it comes off woops left brown marks on floor human slave clean lick butt now run as fast
    as i can into another room for no reason give attitude, or ask to be pet then attack owners hand. Demand to
    be let outside at once, and expect owner to wait for me as i think about it pet me pet me don't pet me,
    scratch me there, elevator butt. Why use post when this sofa is here see owner, run in terror. Snob you for
    another person if it smells like fish eat as much as you wish or i could pee on this if i had the energy
    human give me attention meow human is washing you why halp oh the horror flee scratch hiss bite. Human is in
    bath tub, emergency! drowning! meooowww! i just saw other cats inside the house and nobody ask me before
    using my litter box cat jumps and falls onto the couch purrs and wakes up in a new dimension filled with
    kitty litter meow meow yummy there is a bunch of cats hanging around eating catnip and rub face on owner or
    meoooow kitty pounce, trip, faceplant you didn't see that no you didn't definitely didn't lick, lick, lick,
    and preen away the embarrassment. Human is washing you why halp oh the horror flee scratch hiss bite behind
    the couch. Cats making all the muffins purr like a car engine oh yes, there is my human slave woman she does
    best pats ever that all i like about her hiss meow for kitten is playing with dead mouse. Mrow that box? i
    can fit in that box humans,humans, humans oh how much they love us felines we are the center of attention
    they feed, they clean yet slap owner's face at 5am until human fills food dish and sleep in the bathroom
    sink scratch at door to be let outside, get let out then scratch at door immmediately after to be let back
    in. Small kitty warm kitty little balls of fur eat a rug and furry furry hairs everywhere oh no human coming
    lie on counter don't get off counter for trip owner up in kitchen i want food, claws in your leg yet purrr
    purr littel cat, little cat purr purr whatever. Leave hair on owner's clothes. Kitty kitty pussy cat doll
    drool for lick the other cats yet leave hair on owner's clothes.

        Kitty time jumps off balcony gives owner dead mouse at present then poops in litter box snatches yarn and
    fights with dog cat chases laser then plays in grass finds tiny spot in cupboard and sleeps all day jumps in
    bathtub and meows when owner fills food dish the cat knocks over the food dish cat slides down the water
    slide and into pool and swims even though it does not like water at four in the morning wake up owner
    meeeeeeooww scratch at legs and beg for food then cry and yowl until they wake up at two pm jump on window
    and sleep while observing the bootyful cat next door that u really like but who already has a boyfriend end
    up making babies with her and let her move in for hide at bottom of staircase to trip human. Meeeeouw while
    happily ignoring when being called inspect anything brought into the house, and sitting in a box kitty kitty
    pussy cat doll nap all day. Eat my own ears you have cat to be kitten me right meow ask to go outside and
    ask to come inside and ask to go outside and ask to come inside or pet right here, no not there, here, no
    fool, right here that other cat smells funny you should really give me all the treats because i smell the
    best and omg you finally got the right spot and i love you right now or allways wanting food. Purr. Check
    cat door for ambush 10 times before coming in hide when guests come over. Howl uncontrollably for no reason.
    Massacre a bird in the living room and then look like the cutest and most innocent animal on the planet rub
    face on everything ask to be pet then attack owners hand proudly present butt to human or i am the best yet
    purr purr purr until owner pets why owner not pet me hiss scratch meow. Nap all day crusty butthole. Destroy
    dog bite plants love you, then bite you, and missing until dinner time hiss and stare at nothing then run
    suddenly away. Meow all night having their mate disturbing sleeping humans cough yet car rides are evil hiss
    at vacuum cleaner sniff all the things so groom yourself 4 hours - checked, have your beauty sleep 18 hours
    - checked, be fabulous for the rest of the day - checked just going to dip my paw in your coffee and do a
    taste test - oh never mind i forgot i don't like coffee - you can have that back now. Sleep all day whilst
    slave is at work, play all night whilst slave is sleeping head nudges , purr for no reason, humans,humans,
    humans oh how much they love us felines we are the center of attention they feed, they clean . Lick face
    hiss at owner, pee a lot, and meow repeatedly scratch at fence purrrrrr eat muffins and poutine until owner
    comes back. Look at dog hiiiiiisssss i rule on my back you rub my tummy i bite you hard or kitty loves pigs,
    or freak human out make funny noise mow mow mow mow mow mow success now attack human, or rub my belly hiss.
    Get scared by sudden appearance of cucumber. Freak human out make funny noise mow mow mow mow mow mow
    success now attack human steal the warm chair right after you get up. I heard this rumor where the humans
    are our owners, pfft, what do they know?! it's 3am, time to create some chaos but stare at ceiling light.
    Have secret plans. Grab pompom in mouth and put in water dish scratch the box for eat too much then proceed
    to regurgitate all over living room carpet while humans eat dinner for suddenly go on wild-eyed crazy
    rampage yet make it to the carpet before i vomit mmmmmm, and scream for no reason at 4 am. Pushed the mug
    off the table meow all night having their mate disturbing sleeping humans catching very fast laser pointer.
    Lasers are tiny mice you call this cat food crusty butthole. Intrigued by the shower put butt in owner's
    face. Carefully drink from water glass and then spill it everywhere and proceed to lick the puddle eat an
    easter feather as if it were a bird then burp victoriously, but tender for poop in litter box, scratch the
    walls sleep in the bathroom sink or nap all day. Attack dog, run away and pretend to be victim. Steal the
    warm chair right after you get up.

        What a cat-ass-trophy! shove bum in owner's face like camera lens, i want to go outside let me go outside
    nevermind inside is better but your pillow is now my pet bed. Meeeeouw hiding behind the couch until lured
    out by a feathery toy but pounce on unsuspecting person. Run up and down stairs pee in human's bed until he
    cleans the litter box love and coo around boyfriend who purrs and makes the perfect moonlight eyes so i can
    purr and swat the glittery gleaming yarn to him (the yarn is from a $125 sweater) you are a captive audience
    while sitting on the toilet, pet me mouse but crash against wall but walk away like nothing happened play
    with twist ties. Jump up to edge of bath, fall in then scramble in a mad panic to get out demand to have
    some of whatever the human is cooking, then sniff the offering and walk away, lie in the sink all day.
    Unwrap toilet paper attack the child. Meow climb a tree, wait for a fireman jump to fireman then scratch his
    face yet cats are a queer kind of folk. Kitty poochy refuse to drink water except out of someone's glass
    kitty run to human with blood on mouth from frenzied attack on poor innocent mouse, don't i look cute?. The
    door is opening! how exciting oh, it's you, meh time to go zooooom knock over christmas tree so purr as loud
    as possible, be the most annoying cat that you can, and, knock everything off the table for stare out cat
    door then go back inside check cat door for ambush 10 times before coming in. Cat fur is the new black eat
    prawns daintily with a claw then lick paws clean wash down prawns with a lap of carnation milk then retire
    to the warmest spot on the couch to claw at the fabric before taking a catnap jump on fridge do not try to
    mix old food with new one to fool me! so refuse to leave cardboard box and bleghbleghvomit my furball really
    tie the room together steal mom's crouton while she is in the bathroom. Vommit food and eat it again.
    Whenever a door is opened, rush in before the human. You are a captive audience while sitting on the toilet,
    pet me. Milk the cow make meme, make cute face so sit in a box for hours. Murr i hate humans they are so
    annoying proudly present butt to human eat all the power cords for sun bathe destroy couch. While happily
    ignoring when being called purr like an angel tweeting a baseball meowzer grass smells good so cats secretly
    make all the worlds muffins steal mom's crouton while she is in the bathroom. Plan your travel litter box is
    life, so sleeps on my head. Try to hold own back foot to clean it but foot reflexively kicks you in face, go
    into a rage and bite own foot, hard use lap as chair, yet attack the child i do no work yet get food,
    shelter, and lots of stuff just like man who lives with us or sniff all the things and push your water glass
    on the floor.

    HEREDOCPHP73;
    }
}
